==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Etkinlikler",
    "An error occurred while loading activities" : "Etkinlikler yüklenirken bir sorun çıktı",
    "No activity yet" : "Henüz bir etkinlik yok",
    "Load more activities" : "Diğer etkinlikleri yükle",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "Home" : "Giriş",
    "{name} (invisible)" : "{name} (görüntülenmez)",
    "{name} (restricted)" : "{name} (kısıtlı)",
    "in {path}" : "{path} içinde",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşım gibi olaylar görüntülenir",
    "There are no events for this filter" : "Bu süzgeçte herhangi bir olay yok",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "Open file" : "Dosya aç",
    "Personal activity feed for %s" : "%s kişisel etkinlik akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Settings have been updated." : "Ayarlar güncellendi",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "All activities" : "Tüm etkinlikler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "Hello %s" : "Merhaba %s",
    "Hello %s," : "Merhaba %s,",
    "There was some activity at %s" : "%s üzerinde bazı etkinlik görüldü",
    "_and %n more _::_and %n more _" : ["ve %n diğer","ve %n diğer"],
    "Activity notification" : "Etkinlik bildirimi",
    ", " : ", ",
    "%s and %s" : "%s ve %s",
    "Activity" : "Etkinlik",
    "Activity feed" : "Etkinlik akışı",
    "Send activity emails" : "Etkinlik e-postaları gönder",
    "Default settings" : "Varsayılan ayarlar",
    "Configure the default activity settings for new users." : "Yeni kullanıcılar için varsayılan etkinlik ayarlarını yapılandırın.",
    "List your own actions in the stream" : "Akışta kendi etkinliklerinizi görüntüleyin",
    "Notify about your own actions via email" : "Kendi etkinlikleriniz e-posta ile bildirilsin",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send emails:" : "E-posta gönderimi:",
    "As soon as possible" : "Olabildiğince çabuk",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "E-posta bildirimlerinin gönderilmesini ve uygulama etkinlik akışında yer almasını istediğiniz etkinlikleri seçin.",
    "Choose which activities you want to see in your stream." : "Akışınızda yer almasını istediğiniz işlemleri seçin.",
    "Settings" : "Ayarlar",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "RSS feed" : "RSS akışı",
    "No more events to load" : "Yüklenecek başka bir olay yok",
    "Files" : "Dosyalar",
    "Error loading activities" : "Etkinlikler yüklenirken hata",
    "No activities" : "Etkinlik yok",
    "You are receiving this email because the following things happened at %s" : "Bu e-posta %s üzerinde aşağıdaki etkinliklerin gerçekleştiğini bildirmek üzere gönderilmiştir:",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* ve %n diğer","* ve %n diğer"]
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Etkinlikler",
    "An error occurred while loading activities" : "Etkinlikler yüklenirken bir sorun çıktı",
    "No activity yet" : "Henüz bir etkinlik yok",
    "Load more activities" : "Diğer etkinlikleri yükle",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "Home" : "Giriş",
    "{name} (invisible)" : "{name} (görüntülenmez)",
    "{name} (restricted)" : "{name} (kısıtlı)",
    "in {path}" : "{path} içinde",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşım gibi olaylar görüntülenir",
    "There are no events for this filter" : "Bu süzgeçte herhangi bir olay yok",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "Open file" : "Dosya aç",
    "Personal activity feed for %s" : "%s kişisel etkinlik akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Settings have been updated." : "Ayarlar güncellendi",
    "All activities" : "Tüm etkinlikler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "\"remote user\"" : "\"uzak kullanıcı\"",
    "Activity notification for %s" : "%s için etkinlik bildirimi",
    "Hello %s" : "Merhaba %s",
    "Hello %s," : "Merhaba %s,",
    "There was some activity at %s" : "%s üzerinde bazı etkinlik görüldü",
    "_and %n more _::_and %n more _" : ["ve %n diğer","ve %n diğer"],
    ", " : ", ",
    "%s and %s" : "%s ve %s",
    "Mail" : "Posta",
    "Stream" : "Akış",
    "Activity" : "Etkinlik",
    "Activity feed" : "Etkinlik akışı",
    "Send activity emails" : "Etkinlik e-postaları gönder",
    "Default settings" : "Varsayılan ayarlar",
    "Configure the default activity settings for new users." : "Yeni kullanıcılar için varsayılan etkinlik ayarlarını yapılandırın.",
    "List your own actions in the stream" : "Akışta kendi etkinliklerinizi görüntüleyin",
    "Notify about your own actions via email" : "Kendi etkinlikleriniz e-posta ile bildirilsin",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send emails:" : "E-posta gönderimi:",
    "As soon as possible" : "Olabildiğince çabuk",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "E-posta bildirimlerinin gönderilmesini ve uygulama etkinlik akışında yer almasını istediğiniz etkinlikleri seçin.",
    "Choose which activities you want to see in your stream." : "Akışınızda yer almasını istediğiniz işlemleri seçin.",
    "Settings" : "Ayarlar",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "RSS feed" : "RSS akışı",
    "No more events to load" : "Yüklenecek başka bir olay yok",
    "Files" : "Dosyalar",
    "Activity notification" : "Etkinlik bildirimi"
},
"nplurals=2; plural=(n > 1);");
